agentle.agents.templates.data\_collection.progressive\_profilling\_agent
========================================================================

.. automodule:: agentle.agents.templates.data_collection.progressive_profilling_agent

   
   .. rubric:: Functions

   .. autosummary::
   
      PrivateAttr
      asynccontextmanager
      cast
      contextmanager
      dedent
   
   .. rubric:: Classes

   .. autosummary::
   
      Agent
      AgentRunOutput
      Any
      AssistantMessage
      AsyncGenerator
      BaseModel
      CollectedData
      ConfigDict
      Context
      DeveloperMessage
      FieldSpec
      FilePart
      GenerationProvider
      Generator
      Mapping
      MutableMapping
      MutableSequence
      ProgressiveProfilingAgent
      Sequence
      TextPart
      UserMessage
   